@@ -10,8 +10,9 @@ CPAN
 =cut
 
 
-package Bio::Kmer 0.07;
+package Bio::Kmer;
 require 5.12.0;
+our $VERSION=0.08;
 
 use strict;
 use warnings;
